<?php

namespace backend\modules\reports\controllers;

use backend\modules\master\models\Category;
use backend\modules\master\models\Product;
use backend\modules\master\models\Vendor;
use backend\modules\reports\models\SalesFastSlowMovingReport;
use Mpdf\Mpdf;
use yii\data\ActiveDataProvider;
use yii\helpers\ArrayHelper;
use Yii;
use PHPExcel;
use PHPExcel_IOFactory;


class SalesMovingProductController extends \yii\web\Controller
{
    public function actionIndex($print=null,$excel=null)
    {
        $model = new SalesFastSlowMovingReport();
        $query = SalesFastSlowMovingReport::find();
        if(Yii::$app->request->get()){
            $model->load(Yii::$app->request->queryParams);
            $query->andFilterWhere(['vendor_name'=> $model->v_name])
                ->andFilterWhere(['between','date', $model->from_date,$model->to_date])
                ->andFilterWhere(['category_id'=>$model->cat]);
                // ->andFilterWhere(['executive'=>$model->executive]);
            if($model->type == 1){
                 $query->orderBy(['product_sold'=>SORT_DESC]);
            }else{
                $query->orderBy(['product_sold'=>SORT_ASC]);
            }
        }

        $dataProvider = new ActiveDataProvider([
            'query'=>$query,
        ]);
        if($print!=null)
        {
            $dataProvider->pagination = false;
            $mpdf = new mPDF;
            $mpdf->showImageErrors = true;
            $mpdf->WriteHTML($this->renderPartial('/sales-moving-product/exportpdf', [
                'dataProvider' => $dataProvider,
                'model'=>$model,

            ]));
            if($print=='true')
            {
                $mpdf->Output('sale-moving-product.pdf', 'D');
            }
            else
            {
                $mpdf->Output('sale-moving-product.pdf', 'I');
            }
            
        }
        if($excel !=null){
            $this->actionExcelReport($dataProvider);
        }
        return $this->render('index',[
            'model'=> $model,
            'dataProvider'=> $dataProvider
        ]);
    }
    public function actionVendordetails($searchTerm=null)
    {
        if(!$searchTerm)
            $product=Vendor::find()->limit(10)->all();
        else
            $product=Vendor::find()->where(["like","business_name",$searchTerm])->limit(10)->all();

        $productlist=ArrayHelper::map($product, 'business_name', 'business_name');
        return json_encode($productlist);
    }
    public function actionProductdetails($searchTerm=null)
    {
        if(!$searchTerm)
            $product=Category::find()->limit(10)->all();
        else
            $product=Category::find()->where(["like","name",$searchTerm])->limit(10)->all();

        $productlist=ArrayHelper::map($product, 'id', 'name');
        return json_encode($productlist);
    }
    public function actionExportPdf()
    {
        $model = new SalesFastSlowMovingReport();
        $query=SalesFastSlowMovingReport::find()->orderBy(['product_sold'=>SORT_DESC]);
        $dataProvider = new ActiveDataProvider([
            'query' => $query,
        ]);
        $dataProvider->pagination = false;
        $mpdf = new mPDF;
        $mpdf->WriteHTML($this->renderPartial('/sales-moving-product/exportpdf', [
            'dataProvider' => $dataProvider,
                'model' => $model
        ]));
        $mpdf->Output('sale-moving-product.pdf', 'D');
    }

    public function actionExcelReport($data=null)
    {
        if ($data != null){
            $dataProvider = $data;
        }else{

            $query = SalesFastSlowMovingReport::find()->orderBy(['product_sold'=>SORT_DESC]);

            $dataProvider = new ActiveDataProvider([
                'query'=> $query,
                'pagination'=>false,
            ]);

        }

        $phpExcel = new PHPExcel;
        $phpExcel->getDefaultStyle()->getFont()->setName('Calibri');
        $phpExcel ->getProperties()->setDescription("Excel SpreadSheet in PHP");
        $writer = PHPExcel_IOFactory::createWriter($phpExcel, "Excel2007");
        $sheet = $phpExcel ->getActiveSheet();
        // $sheet->setTitle('My product list');
        $sheet ->getCell('A1')->setValue('MOHAPATRA SCIENTIFIC PRIVATE LIMITED');
        $sheet ->getCell('A2')->setValue('F2G/30, INDRADHANU MARKET, IRC VILLAGE,');
        $sheet ->getCell('A3')->setValue('BHUBANESWAR, Odisha');
        $sheet ->getCell('A4')->setValue('Purchase Report');
        $sheet ->getCell('A5')->setValue('');
        // Making headers text bold and larger
        $sheet->getStyle('A1:D1')->getFont()->setBold(true)->setSize(11);
        $sheet->getStyle('A2:D2')->getFont()->setSize(11);
        $sheet->getStyle('A3:D3')->getFont()->setSize(11);
        $sheet->getStyle('A4:D4')->getFont()->setSize(11);
        $sheet->getStyle('A5:D5')->getFont()->setSize(11);

        $sheet->getColumnDimension('A')->setWidth(50);
        $sheet->getColumnDimension('B')->setWidth(40);
        $sheet->getColumnDimension('C')->setWidth(20);
        $sheet->getColumnDimension('D')->setWidth(20);

        $sheet->mergeCells('A1:D1');
        $sheet->mergeCells('A2:D2');
        $sheet->mergeCells('A3:D3');
        $sheet->mergeCells('A4:D4');
        $sheet->mergeCells('A5:D5');

        $sheet->setCellValue('A6',  'Product Name');
        $sheet->setCellValue('B6',  'Product Description');
        $sheet->setCellValue('C6',  'Barcode');
        $sheet->setCellValue('D6',  'Product Sold');

        $row=7;
        $total_qty=0;
        $total_items=0;
        if (!empty($dataProvider->getModels())) {
            foreach ($dataProvider->getModels() as $key => $val) {
                $total_qty+=$val->product_sold;
                $total_items ++;
            }
        }

        foreach ($dataProvider->models as $model)
        {
            $sheet->getStyle('A'.$row)->getAlignment()->setWrapText(true);

            $sheet->setCellValue('A' . $row,  $model->product_name);
            $sheet->setCellValue('B' . $row,  $model->description);
            $prod = Product::find()->where(['id'=>$model->product_id])->one();
            $sheet->setCellValue('C' . $row,  (string)$prod->barcode);
            $sheet->setCellValue('D' . $row, (string)$model->product_sold);
            $row++;
        }
        $sheet->setCellValue('C' . $row,'Total Item Sold:' .$total_items);
        $sheet->setCellValue('D' . $row, (string)$total_qty);


        ob_clean();
        ob_start();

        header('Content-type: application/vnd.ms-excel'); // It will be called file.xls
        header('Content-Disposition: attachment; filename="Sale-moving-product.xlsx"'); // Write file to the browser

        $writer->save('php://output');
        ob_flush();
        exit();






    }



}
